package pmbtest;

use strict;
use 5.008_005;
use version;

our $VERSION = version->declare('v1.1.2');

1;
__END__

=encoding utf-8

=head1 NAME

pmbtest - Blah blah blah

=head1 SYNOPSIS

  use pmbtest;

=head1 DESCRIPTION

pmbtest is

=head1 AUTHOR

Philipp Busse E<lt>philipp.busse@gmx.netE<gt>

=head1 COPYRIGHT

Copyright 2021- Philipp Busse

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=cut
